ytree\.tree\_farm\.ancestry\_short\.above\_mass\_fraction
=========================================================

.. currentmodule:: ytree.tree_farm.ancestry_short

.. autofunction:: above_mass_fraction